@@ -19,12 +19,14 @@ import (
 	log "github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
-	pb "gitlab.com/gitlab-org/gitaly-proto/go"
+
+	"gitlab.com/gitlab-org/gitaly-proto/go/gitalypb"
 
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/api"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/config"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/gitaly"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/helper"
+	"gitlab.com/gitlab-org/gitlab-workhorse/internal/secret"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/testhelper"
 	"gitlab.com/gitlab-org/gitlab-workhorse/internal/upstream"
 )
@@ -380,37 +382,6 @@ func TestSendURLForArtifacts(t *testing.T) {
 	assert.Equal(t, fileContents, string(body), "GET %q: response body", resourcePath)
 }
 
-func TestGetGitDiff(t *testing.T) {
-	fromSha := "be93687618e4b132087f430a4d8fc3a609c9b77c"
-	toSha := "54fcc214b94e78d7a41a9a8fe6d87a5e59500e51"
-	jsonParams := fmt.Sprintf(`{"RepoPath":"%s","ShaFrom":"%s","ShaTo":"%s"}`, path.Join(testRepoRoot, testRepo), fromSha, toSha)
-	expectedBody := "diff --git a/README b/README"
-
-	resp, body, err := doSendDataRequest("/something", "git-diff", jsonParams)
-	require.NoError(t, err)
-
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assert.Equal(t, expectedBody, string(body[:len(expectedBody)]), "GET %q: response body", resp.Request.URL)
-	assert.Equal(t, 155, len(body), "GET %q: body size", resp.Request.URL)
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
-}
-
-func TestGetGitPatch(t *testing.T) {
-	// HEAD of master branch against HEAD of fix branch
-	fromSha := "6907208d755b60ebeacb2e9dfea74c92c3449a1f"
-	toSha := "48f0be4bd10c1decee6fae52f9ae6d10f77b60f4"
-	jsonParams := fmt.Sprintf(`{"RepoPath":"%s","ShaFrom":"%s","ShaTo":"%s"}`, path.Join(testRepoRoot, testRepo), fromSha, toSha)
-
-	resp, body, err := doSendDataRequest("/something", "git-format-patch", jsonParams)
-	require.NoError(t, err)
-
-	assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resp.Request.URL)
-	assertNginxResponseBuffering(t, "no", resp, "GET %q: nginx response buffering", resp.Request.URL)
-
-	// Only the two commits on the fix branch should be included
-	testhelper.AssertPatchSeries(t, body, "12d65c8dd2b2676fa3ac47d955accc085a37a9c1", toSha)
-}
-
 func TestApiContentTypeBlock(t *testing.T) {
 	wrongResponse := `{"hello":"world"}`
 	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`.`), func(w http.ResponseWriter, _ *http.Request) {
@@ -433,7 +404,7 @@ func TestApiContentTypeBlock(t *testing.T) {
 func TestAPIFalsePositivesAreProxied(t *testing.T) {
 	goodResponse := []byte(`<html></html>`)
 	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`.`), func(w http.ResponseWriter, r *http.Request) {
-		if r.Header.Get(api.RequestHeader) != "" && r.Method != "GET" {
+		if r.Header.Get(secret.RequestHeader) != "" && r.Method != "GET" {
 			w.WriteHeader(500)
 			w.Write([]byte("non-GET request went through PreAuthorize handler"))
 		} else {
@@ -478,6 +449,26 @@ func TestAPIFalsePositivesAreProxied(t *testing.T) {
 	}
 }
 
+func TestCorrelationIdHeader(t *testing.T) {
+	ts := testhelper.TestServerWithHandler(regexp.MustCompile(`.`), func(w http.ResponseWriter, r *http.Request) {
+		w.Header().Add("X-Request-Id", "12345678")
+		w.WriteHeader(200)
+	})
+	defer ts.Close()
+	ws := startWorkhorseServer(ts.URL)
+	defer ws.Close()
+
+	for _, resource := range []string{
+		"/api/v3/projects/123/repository/not/special",
+	} {
+		resp, _ := httpGet(t, ws.URL+resource, nil)
+
+		assert.Equal(t, 200, resp.StatusCode, "GET %q: status code", resource)
+		requestIds := resp.Header["X-Request-Id"]
+		assert.Equal(t, 1, len(requestIds), "GET %q: One X-Request-Id present", resource)
+	}
+}
+
 func setupStaticFile(fpath, content string) error {
 	cwd, err := os.Getwd()
 	if err != nil {
@@ -527,27 +518,6 @@ func testAuthServer(url *regexp.Regexp, code int, body interface{}) *httptest.Se
 	})
 }
 
-func archiveOKServer(t *testing.T, archiveName string) *httptest.Server {
-	return testhelper.TestServerWithHandler(regexp.MustCompile("."), func(w http.ResponseWriter, r *http.Request) {
-		cwd, err := os.Getwd()
-		require.NoError(t, err)
-
-		archivePath := path.Join(cwd, cacheDir, archiveName)
-
-		params := struct{ RepoPath, ArchivePath, CommitID, ArchivePrefix string }{
-			repoPath(t),
-			archivePath,
-			"c7fbe50c7c7419d9701eebe64b1fdacc3df5b9dd",
-			"foobar123",
-		}
-		jsonData, err := json.Marshal(params)
-		require.NoError(t, err)
-
-		encodedJSON := base64.URLEncoding.EncodeToString(jsonData)
-		w.Header().Set("Gitlab-Workhorse-Send-Data", "git-archive:"+encodedJSON)
-	})
-}
-
 func newUpstreamConfig(authBackend string) *config.Config {
 	return &config.Config{
 		Version:      "123",
@@ -574,25 +544,16 @@ func runOrFail(t *testing.T, cmd *exec.Cmd) {
 }
 
 func gitOkBody(t *testing.T) *api.Response {
-	repoPath := repoPath(t)
 	return &api.Response{
 		GL_ID:       "user-123",
 		GL_USERNAME: "username",
-		RepoPath:    repoPath,
-		Repository: pb.Repository{
+		Repository: gitalypb.Repository{
 			StorageName:  "default",
 			RelativePath: "foo/bar.git",
 		},
 	}
 }
 
-func repoPath(t *testing.T) string {
-	cwd, err := os.Getwd()
-	require.NoError(t, err)
-
-	return path.Join(cwd, testRepoRoot, testRepo)
-}
-
 func httpGet(t *testing.T, url string, headers map[string]string) (*http.Response, string) {
 	req, err := http.NewRequest("GET", url, nil)
 	require.NoError(t, err)
